# SPDX-License-Identifier: GPL-2.0-or-later


"""
Extending features of the Asset Browser for a studio use. 
"""

bl_info = {
    "name": "Asset Library",
    "description": "Asset Library based on the Asset Browser.",
    "author": "Christophe Seux",
    "version": (2, 0),
    "blender": (4, 0, 2),
    "warning": "In development, things may change",
    "location": "Asset Browser",
    "category": "Import-Export",
}


from . import operators, properties, ui, preferences

modules = (
    operators,
    properties,
    ui,
    preferences
)

# Reload Modules from inside Blender
if "bpy" in locals():
    import importlib
    
    for mod in modules:
        importlib.reload(mod)


def register():
    """Register the addon Asset Library for Blender"""
    
    for mod in modules:
        mod.register()


def unregister():
    """Unregister the addon Asset Library for Blender"""

    for mod in reversed(modules):
        mod.unregister()